@@ -1,8 +1,8 @@
 
-__version__ = "0.12.5"
+__version__ = "0.12.6"
 __version_vcs_info__ = {
-    'branch': 'master',
-    'revid': '367c2b3',
-    'revno': 2153}
+    'branch': 'hotfix-0.12.6',
+    'revid': '5d7df89',
+    'revno': 2156}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
